@@ -9,7 +9,7 @@ from .jc_types import ParserInfoType, JSONDictType
 from jc import appdirs
 
 
-__version__ = '1.23.1'
+__version__ = '1.23.3'
 
 parsers: List[str] = [
     'acpi',
@@ -19,9 +19,11 @@ parsers: List[str] = [
     'asciitable',
     'asciitable-m',
     'blkid',
+    'bluetoothctl',
     'cbt',
     'cef',
     'cef-s',
+    'certbot',
     'chage',
     'cksum',
     'clf',
@@ -74,6 +76,7 @@ parsers: List[str] = [
     'last',
     'ls',
     'ls-s',
+    'lsattr',
     'lsblk',
     'lsmod',
     'lsof',
@@ -158,6 +161,7 @@ parsers: List[str] = [
     'semver',
     'sfdisk',
     'shadow',
+    'srt',
     'ss',
     'ssh-conf',
     'sshd-conf',
@@ -191,12 +195,14 @@ parsers: List[str] = [
     'uptime',
     'url',
     'ver',
+    'veracrypt',
     'vmstat',
     'vmstat-s',
     'w',
     'wc',
     'who',
     'x509-cert',
+    'x509-csr',
     'xml',
     'xrandr',
     'yaml',
